@@ -2,7 +2,6 @@
 
 import ctypes as ct
 import io
-import logging
 import os
 from contextlib import contextmanager
 from typing import Union
@@ -10,11 +9,10 @@ from typing import Union
 import glasswall
 from glasswall import determine_file_type as dft
 from glasswall import utils
+from glasswall.config.logging import log
 from glasswall.libraries.editor import errors, successes
 from glasswall.libraries.library import Library
 
-log = logging.getLogger("glasswall")
-
 
 class Editor(Library):
     """ A high level Python wrapper for Glasswall Editor / Core2. """
@@ -554,7 +552,13 @@ class Editor(Library):
             input_file = utils.as_bytes(input_file)
 
         # Check that file type is supported
-        self.determine_file_type(input_file=input_file)
+        try:
+            self.determine_file_type(input_file=input_file)
+        except dft.errors.FileTypeEnumError:
+            if raise_unsupported:
+                raise
+            else:
+                return None
 
         with utils.CwdHandler(self.library_path):
             with self.new_session() as session:
@@ -562,8 +566,8 @@ class Editor(Library):
                 register_input = self.register_input(session, input_file)
                 register_output = self.register_output(session, output_file=output_file)
                 status = self.run_session(session)
-                # Ensure memory allocated by GW2RegisterPoliciesMemory is not garbage collected until after run_session
-                content_management_policy
+                # Ensure memory allocated is not garbage collected until after run_session
+                content_management_policy, register_input, register_output
 
         if status not in successes.success_codes:
             if raise_unsupported:
@@ -642,7 +646,13 @@ class Editor(Library):
             raise TypeError(raise_unsupported)
 
         # Check that file type is supported
-        self.determine_file_type(input_file=input_file)
+        try:
+            self.determine_file_type(input_file=input_file)
+        except dft.errors.FileTypeEnumError:
+            if raise_unsupported:
+                raise
+            else:
+                return None
 
         # Convert string path arguments to absolute paths
         if isinstance(input_file, str):
@@ -666,8 +676,8 @@ class Editor(Library):
                 register_input = self.register_input(session, input_file)
                 register_analysis = self.register_analysis(session, output_file)
                 status = self.run_session(session)
-                # Ensure memory allocated by GW2RegisterPoliciesMemory is not garbage collected until after run_session
-                content_management_policy
+                # Ensure memory allocated is not garbage collected until after run_session
+                content_management_policy, register_input, register_analysis
 
         if status not in successes.success_codes:
             if raise_unsupported:
@@ -810,7 +820,13 @@ class Editor(Library):
             raise TypeError(raise_unsupported)
 
         # Check that file type is supported
-        self.determine_file_type(input_file=input_file)
+        try:
+            self.determine_file_type(input_file=input_file)
+        except dft.errors.FileTypeEnumError:
+            if raise_unsupported:
+                raise
+            else:
+                return None
 
         # Convert string path arguments to absolute paths
         if isinstance(input_file, str):
@@ -834,8 +850,8 @@ class Editor(Library):
                 register_input = self.register_input(session, input_file)
                 register_export = self.register_export(session, output_file)
                 status = self.run_session(session)
-                # Ensure memory allocated by GW2RegisterPoliciesMemory is not garbage collected until after run_session
-                content_management_policy
+                # Ensure memory allocated is not garbage collected until after run_session
+                content_management_policy, register_input, register_export
 
         if status not in successes.success_codes:
             log.warning(f"\n\tsession: {session}\n\tstatus: {status}")
@@ -983,7 +999,13 @@ class Editor(Library):
             raise TypeError(raise_unsupported)
 
         # Check that file type is supported
-        self.determine_file_type(input_file=input_file)
+        try:
+            self.determine_file_type(input_file=input_file)
+        except dft.errors.FileTypeEnumError:
+            if raise_unsupported:
+                raise
+            else:
+                return None
 
         # Convert string path arguments to absolute paths
         if isinstance(input_file, str):
@@ -1007,8 +1029,8 @@ class Editor(Library):
                 register_import = self.register_import(session, input_file)
                 register_output = self.register_output(session, output_file)
                 status = self.run_session(session)
-                # Ensure memory allocated by GW2RegisterPoliciesMemory is not garbage collected until after run_session
-                content_management_policy
+                # Ensure memory allocated is not garbage collected until after run_session
+                content_management_policy, register_import, register_output
 
         if status not in successes.success_codes:
             log.warning(f"\n\tsession: {session}\n\tstatus: {status}")
