@@ -2,18 +2,16 @@
 
 import ctypes as ct
 import io
-import logging
 import os
 from typing import Union
 
 import glasswall
 from glasswall import determine_file_type as dft
 from glasswall import utils
+from glasswall.config.logging import log
 from glasswall.libraries.library import Library
 from glasswall.libraries.rebuild import errors, successes
 
-log = logging.getLogger("glasswall")
-
 
 class Rebuild(Library):
     """ A high level Python wrapper for Glasswall Rebuild / Classic. """
@@ -30,7 +28,6 @@ class Rebuild(Library):
 
         log.info(f"Loaded Glasswall {self.__class__.__name__} version {self.version()} from {self.library_path}")
 
-
     def validate_license(self):
         """ Validates the license of the library by attempting to call protect_file on a known supported file.
 
@@ -224,7 +221,13 @@ class Rebuild(Library):
             content_management_policy = os.path.abspath(content_management_policy)
 
         # Check that file type is supported
-        file_type = self.determine_file_type(input_file=input_file)
+        try:
+            file_type = self.determine_file_type(input_file=input_file)
+        except dft.errors.FileTypeEnumError:
+            if raise_unsupported:
+                raise
+            else:
+                return None
 
         # Convert memory inputs to bytes
         if isinstance(input_file, (bytes, bytearray, io.BytesIO)):
@@ -403,7 +406,13 @@ class Rebuild(Library):
             content_management_policy = os.path.abspath(content_management_policy)
 
         # Check that file type is supported
-        file_type = self.determine_file_type(input_file=input_file)
+        try:
+            file_type = self.determine_file_type(input_file=input_file)
+        except dft.errors.FileTypeEnumError:
+            if raise_unsupported:
+                raise
+            else:
+                return None
 
         # Convert memory inputs to bytes
         if isinstance(input_file, (bytes, bytearray, io.BytesIO)):
@@ -580,7 +589,13 @@ class Rebuild(Library):
             content_management_policy = os.path.abspath(content_management_policy)
 
         # Check that file type is supported
-        self.determine_file_type(input_file=input_file)
+        try:
+            self.determine_file_type(input_file=input_file)
+        except dft.errors.FileTypeEnumError:
+            if raise_unsupported:
+                raise
+            else:
+                return None
 
         # Convert memory inputs to bytes
         if isinstance(input_file, (bytes, bytearray, io.BytesIO)):
@@ -748,7 +763,13 @@ class Rebuild(Library):
             content_management_policy = os.path.abspath(content_management_policy)
 
         # Check that file type is supported
-        self.determine_file_type(input_file=input_file)
+        try:
+            self.determine_file_type(input_file=input_file)
+        except dft.errors.FileTypeEnumError:
+            if raise_unsupported:
+                raise
+            else:
+                return None
 
         # Convert memory inputs to bytes
         if isinstance(input_file, (bytes, bytearray, io.BytesIO)):
